@@ -23,8 +23,9 @@ def openapiart():
     openapiart = openapiart_class(api_files=api_files, 
         output_dir='./.output/openapiart', 
         python_module_name='sanity',
-        protobuf_file_name='sanity')
-
+        protobuf_file_name='sanity',
+        protobuf_package_name='test.sanity',
+        extension_prefix='sanity')
     return openapiart
 
 
